@@ -1,7 +1,8 @@
-__version__ = '0.0.5'
+__version__ = "0.0.13"
 
 from rcv_cruncher.cvr.base import CastVoteRecord
 from rcv_cruncher.marks import BallotMarks
 from rcv_cruncher.rcv.base import RCV
 
 from rcv_cruncher.rcv.variants import *
+from rcv_cruncher.parsers import *
